==> zio-aws-gamelift_2.12-5.20.7.1-sources.jar: zio/aws/gamelift/model/RuntimeConfiguration.scala <==
package zio.aws.gamelift.model
import zio.aws.gamelift.model.primitives.{
  GameSessionActivationTimeoutSeconds,
  MaxConcurrentGameSessionActivations
}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class RuntimeConfiguration(
    serverProcesses: Optional[Iterable[zio.aws.gamelift.model.ServerProcess]] =
      Optional.Absent,
    maxConcurrentGameSessionActivations: Optional[
      MaxConcurrentGameSessionActivations
    ] = Optional.Absent,
    gameSessionActivationTimeoutSeconds: Optional[
      GameSessionActivationTimeoutSeconds
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.gamelift.model.RuntimeConfiguration = {
    import RuntimeConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.gamelift.model.RuntimeConfiguration
      .builder()
      .optionallyWith(
        serverProcesses.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.serverProcesses)
      .optionallyWith(
        maxConcurrentGameSessionActivations.map(value =>
          MaxConcurrentGameSessionActivations.unwrap(value): Integer
        )
      )(_.maxConcurrentGameSessionActivations)
      .optionallyWith(
        gameSessionActivationTimeoutSeconds.map(value =>
          GameSessionActivationTimeoutSeconds.unwrap(value): Integer
        )
      )(_.gameSessionActivationTimeoutSeconds)
      .build()
  }
  def asReadOnly: zio.aws.gamelift.model.RuntimeConfiguration.ReadOnly =
    zio.aws.gamelift.model.RuntimeConfiguration.wrap(buildAwsValue())
}
object RuntimeConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.gamelift.model.RuntimeConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.gamelift.model.RuntimeConfiguration =
      zio.aws.gamelift.model.RuntimeConfiguration(
        serverProcesses.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxConcurrentGameSessionActivations.map(value => value),
        gameSessionActivationTimeoutSeconds.map(value => value)
      )
    def serverProcesses
        : Optional[List[zio.aws.gamelift.model.ServerProcess.ReadOnly]]
    def maxConcurrentGameSessionActivations
        : Optional[MaxConcurrentGameSessionActivations]
    def gameSessionActivationTimeoutSeconds
        : Optional[GameSessionActivationTimeoutSeconds]
    def getServerProcesses: ZIO[Any, AwsError, List[
      zio.aws.gamelift.model.ServerProcess.ReadOnly
    ]] = AwsError.unwrapOptionField("serverProcesses", serverProcesses)
    def getMaxConcurrentGameSessionActivations
        : ZIO[Any, AwsError, MaxConcurrentGameSessionActivations] =
      AwsError.unwrapOptionField(
        "maxConcurrentGameSessionActivations",
        maxConcurrentGameSessionActivations
      )
    def getGameSessionActivationTimeoutSeconds
        : ZIO[Any, AwsError, GameSessionActivationTimeoutSeconds] =
      AwsError.unwrapOptionField(
        "gameSessionActivationTimeoutSeconds",
        gameSessionActivationTimeoutSeconds
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.gamelift.model.RuntimeConfiguration
  ) extends zio.aws.gamelift.model.RuntimeConfiguration.ReadOnly {
    override val serverProcesses
        : Optional[List[zio.aws.gamelift.model.ServerProcess.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.serverProcesses())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.gamelift.model.ServerProcess.wrap(item)
          }.toList
        )
    override val maxConcurrentGameSessionActivations
        : Optional[MaxConcurrentGameSessionActivations] = zio.aws.core.internal
      .optionalFromNullable(impl.maxConcurrentGameSessionActivations())
      .map(value =>
        zio.aws.gamelift.model.primitives
          .MaxConcurrentGameSessionActivations(value)
      )
    override val gameSessionActivationTimeoutSeconds
        : Optional[GameSessionActivationTimeoutSeconds] = zio.aws.core.internal
      .optionalFromNullable(impl.gameSessionActivationTimeoutSeconds())
      .map(value =>
        zio.aws.gamelift.model.primitives
          .GameSessionActivationTimeoutSeconds(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.gamelift.model.RuntimeConfiguration
  ): zio.aws.gamelift.model.RuntimeConfiguration.ReadOnly = new Wrapper(impl)
}

==> zio-aws-gamelift_2.13-5.17.116.2-sources.jar: zio/aws/gamelift/model/RuntimeConfiguration.scala <==
package zio.aws.gamelift.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.gamelift.model.primitives.{
  GameSessionActivationTimeoutSeconds,
  MaxConcurrentGameSessionActivations
}
import scala.jdk.CollectionConverters._
final case class RuntimeConfiguration(
    serverProcesses: Option[Iterable[zio.aws.gamelift.model.ServerProcess]] =
      None,
    maxConcurrentGameSessionActivations: Option[
      MaxConcurrentGameSessionActivations
    ] = None,
    gameSessionActivationTimeoutSeconds: Option[
      GameSessionActivationTimeoutSeconds
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.gamelift.model.RuntimeConfiguration = {
    import RuntimeConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.gamelift.model.RuntimeConfiguration
      .builder()
      .optionallyWith(
        serverProcesses.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.serverProcesses)
      .optionallyWith(
        maxConcurrentGameSessionActivations.map(value =>
          MaxConcurrentGameSessionActivations.unwrap(value): Integer
        )
      )(_.maxConcurrentGameSessionActivations)
      .optionallyWith(
        gameSessionActivationTimeoutSeconds.map(value =>
          GameSessionActivationTimeoutSeconds.unwrap(value): Integer
        )
      )(_.gameSessionActivationTimeoutSeconds)
      .build()
  }
  def asReadOnly: zio.aws.gamelift.model.RuntimeConfiguration.ReadOnly =
    zio.aws.gamelift.model.RuntimeConfiguration.wrap(buildAwsValue())
}
object RuntimeConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.gamelift.model.RuntimeConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.gamelift.model.RuntimeConfiguration =
      zio.aws.gamelift.model.RuntimeConfiguration(
        serverProcesses.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxConcurrentGameSessionActivations.map(value => value),
        gameSessionActivationTimeoutSeconds.map(value => value)
      )
    def serverProcesses
        : Option[List[zio.aws.gamelift.model.ServerProcess.ReadOnly]]
    def maxConcurrentGameSessionActivations
        : Option[MaxConcurrentGameSessionActivations]
    def gameSessionActivationTimeoutSeconds
        : Option[GameSessionActivationTimeoutSeconds]
    def getServerProcesses: ZIO[Any, AwsError, List[
      zio.aws.gamelift.model.ServerProcess.ReadOnly
    ]] = AwsError.unwrapOptionField("serverProcesses", serverProcesses)
    def getMaxConcurrentGameSessionActivations
        : ZIO[Any, AwsError, MaxConcurrentGameSessionActivations] =
      AwsError.unwrapOptionField(
        "maxConcurrentGameSessionActivations",
        maxConcurrentGameSessionActivations
      )
    def getGameSessionActivationTimeoutSeconds
        : ZIO[Any, AwsError, GameSessionActivationTimeoutSeconds] =
      AwsError.unwrapOptionField(
        "gameSessionActivationTimeoutSeconds",
        gameSessionActivationTimeoutSeconds
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.gamelift.model.RuntimeConfiguration
  ) extends zio.aws.gamelift.model.RuntimeConfiguration.ReadOnly {
    override val serverProcesses
        : Option[List[zio.aws.gamelift.model.ServerProcess.ReadOnly]] = scala
      .Option(impl.serverProcesses())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.gamelift.model.ServerProcess.wrap(item)
        }.toList
      )
    override val maxConcurrentGameSessionActivations
        : Option[MaxConcurrentGameSessionActivations] = scala
      .Option(impl.maxConcurrentGameSessionActivations())
      .map(value =>
        zio.aws.gamelift.model.primitives
          .MaxConcurrentGameSessionActivations(value)
      )
    override val gameSessionActivationTimeoutSeconds
        : Option[GameSessionActivationTimeoutSeconds] = scala
      .Option(impl.gameSessionActivationTimeoutSeconds())
      .map(value =>
        zio.aws.gamelift.model.primitives
          .GameSessionActivationTimeoutSeconds(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.gamelift.model.RuntimeConfiguration
  ): zio.aws.gamelift.model.RuntimeConfiguration.ReadOnly = new Wrapper(impl)
}
